﻿/* 
  CESYS Software License - Version 1.0 - January 1st, 2016

  Permission is hereby granted, free of charge, to any person or organization
  obtaining a copy of the software and accompanying documentation covered by
  this license (the "Software") to use, reproduce, display, distribute,
  execute, and transmit the Software, and to prepare derivative works of the
  Software, and to permit third-parties to whom the Software is furnished to
  do so, all subject to the following:

  The software must only be used to operate hardware manufactured by 
  CESYS GmbH, Herzogenaurach.

  The copyright notices in the Software and this entire statement, including
  the above license grant, this restriction and the following disclaimer,
  must be included in all copies of the Software, in whole or in part, and
  all derivative works of the Software, unless such copies or derivative
  works are solely in the form of machine-executable object code generated by
  a source language processor.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
  SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
  FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
  
  Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2018
*/  

using System.IO;

namespace BeastLink
{
    /// <summary>
    /// Entry returned by enumeration, valid only between two
    /// enumerations. Call its Open() method to get the
    /// real device handle in form of an instance of type Device.
    /// </summary>
    public sealed class EnumeratedDevice
    {
        private readonly int _eid, _erid;

        internal EnumeratedDevice(DeviceInfo info, int eid, int erid)
        {
            DeviceInfo = info;
            _eid = eid;
            _erid = erid;
        }

        /// <summary>
        /// Get general device info.
        /// </summary>
        public DeviceInfo DeviceInfo { get; private set; }

        /// <summary>
        /// Open this instance, returns object to use for further communication.
        /// An opened device isn't reported in any subsequent enumeration (system wide), until
        /// it's closed.
        /// </summary>
        /// <returns></returns>
        public Device Open()
        {
            if (LibraryInterface._enumRound != _erid)
                throw new IOException("Invalid enumeration round");

            return new Device(DeviceInfo, SystemConnector.BlOpen(_eid));
        }
    }
}
