
# System Clock
create_clock -period 5.000 -name sys_clk -waveform {0.000 2.500} [get_ports sys_clk_p]
set_property PACKAGE_PIN R3 [get_ports sys_clk_p]
set_property IOSTANDARD DIFF_SSTL135 [get_ports sys_clk_p]
# System Reset - ACTIVE HIGH input
set_property PACKAGE_PIN K15 [get_ports sys_rst]
set_property IOSTANDARD LVCMOS33 [get_ports sys_rst]

# Output Clock for FX3 chipset
set_property PACKAGE_PIN N21 [get_ports o_fx3_pclk]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_pclk]

# Input Clock looped back in Hardware
# This is important for the functionality of this IP
set_property PACKAGE_PIN M21 [get_ports i_fx3_pclk]
set_property IOSTANDARD LVCMOS33 [get_ports i_fx3_pclk]
create_clock -period 10.000 -name i_fx3_pclk -waveform {0.000 5.000} [get_ports i_fx3_pclk]
#------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------
# IMPORTANT NOTE:
# DO NOT CHANGE THESE CONSTRAINTS
# AXI-FX3-Interface Constraints
#------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------

# Generated clock constraint for the output clock "o_fx3_pclk"
# This is nothing but the "sys_clk" given to the BeastLink IP
create_generated_clock -name o_pclk -source [get_pins -filter REF_PIN_NAME=~sys_clk* -of [get_cells -hier inst_beastlink*]] -multiply_by 1 [get_ports o_fx3_pclk]

# Timing Constraints on signals related to FX3 Chipset
#------------------------------------------------------------------------------------------------------------------------------------
# FX3 Data Output Delay Constraints
# FX3 Clock to Data Out delay is 8ns, so 2ns before THIS clock edge or 8ns AFTER the PREVIOUS Clock edge

# FX3 needs 8ns to setup its data..!!
set_input_delay -clock i_fx3_pclk -max 8.000 [get_ports io_fx3_fdata]
# FX3 Data Hold is 2ns, so 2ns after THIS clock edge
set_input_delay -clock i_fx3_pclk -min 2.000 [get_ports io_fx3_fdata]
 

# FX3 Data Input Delay Constraints
# FX3 Data Input SETUP is 2 ns, so max is 2
set_output_delay -clock o_pclk -max 2.000 [get_ports io_fx3_fdata]
# FX3 Data Input HOLD is 2 ns, so min is 0.5
set_output_delay -clock o_pclk -min -0.500 [get_ports io_fx3_fdata]


## FX3 Control Signal Constraints
## FX3 CTRL Input SETUP is 2 ns, so max is 2
set_output_delay -clock o_pclk -max 2.000 [get_ports o_fx3_slcs_n]
set_output_delay -clock o_pclk -min -0.500 [get_ports o_fx3_slcs_n]

# *---------------------------------------------------------------------------
set_output_delay -clock o_pclk -max 2.000 [get_ports o_fx3_slwr_n]
set_output_delay -clock o_pclk -min -0.500 [get_ports o_fx3_slwr_n]

set_output_delay -clock o_pclk -max 2.000 [get_ports o_fx3_slrd_n]
set_output_delay -clock o_pclk -min -0.500 [get_ports o_fx3_slrd_n]

set_output_delay -clock o_pclk -max 2.000 [get_ports o_fx3_sloe_n]
set_output_delay -clock o_pclk -min -0.500 [get_ports o_fx3_sloe_n]

set_output_delay -clock o_pclk -max 2.000 [get_ports o_fx3_pktend_n]
set_output_delay -clock o_pclk -min -0.500 [get_ports o_fx3_pktend_n]

set_output_delay -clock o_pclk -max 2.000 [get_ports o_fx3_faddr]
set_output_delay -clock o_pclk -min -0.500 [get_ports o_fx3_faddr]
# *---------------------------------------------------------------------------

set_property SLEW FAST [get_ports o_fx3_slcs_n]
set_property SLEW FAST [get_ports o_fx3_sloe_n]
set_property SLEW FAST [get_ports o_fx3_slrd_n]
set_property SLEW FAST [get_ports o_fx3_slwr_n]
set_property SLEW FAST [get_ports {io_fx3_fdata[31]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[30]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[29]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[28]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[27]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[26]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[25]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[24]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[23]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[22]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[21]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[20]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[19]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[18]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[17]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[16]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[15]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[14]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[13]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[12]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[11]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[10]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[9]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[8]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[7]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[6]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[5]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[4]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[3]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[2]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[1]}]
set_property SLEW FAST [get_ports {io_fx3_fdata[0]}]

set_property DRIVE 16 [get_ports {io_fx3_fdata[31]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[30]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[29]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[28]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[27]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[26]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[25]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[24]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[23]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[22]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[21]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[20]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[19]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[18]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[17]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[16]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[15]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[14]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[13]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[12]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[11]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[10]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[9]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[8]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[7]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[6]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[5]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[4]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[3]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[2]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[1]}]
set_property DRIVE 16 [get_ports {io_fx3_fdata[0]}]
set_property DRIVE 16 [get_ports o_fx3_slcs_n]
set_property DRIVE 16 [get_ports o_fx3_sloe_n]
set_property DRIVE 16 [get_ports o_fx3_slrd_n]
set_property DRIVE 16 [get_ports o_fx3_slwr_n]
set_property DRIVE 16 [get_ports o_fx3_pktend_n]
set_property DRIVE 16 [get_ports {o_fx3_faddr[1]}]
set_property DRIVE 16 [get_ports {o_fx3_faddr[0]}]

# FX3 Control pin Locations
set_property PACKAGE_PIN L19 [get_ports o_fx3_pktend_n]
set_property PACKAGE_PIN M22 [get_ports o_fx3_slcs_n]
set_property PACKAGE_PIN K17 [get_ports o_fx3_sloe_n]
set_property PACKAGE_PIN K16 [get_ports o_fx3_slrd_n]
set_property PACKAGE_PIN M19 [get_ports o_fx3_slwr_n]
set_property PACKAGE_PIN N22 [get_ports {o_fx3_faddr[1]}]
set_property PACKAGE_PIN P20 [get_ports {o_fx3_faddr[0]}]

set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_pktend_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_slcs_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_sloe_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_slrd_n]
set_property IOSTANDARD LVCMOS33 [get_ports o_fx3_slwr_n]
set_property IOSTANDARD LVCMOS33 [get_ports {o_fx3_faddr[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {o_fx3_faddr[0]}]

# FX3 Flag pin Locations
set_property PACKAGE_PIN R18 [get_ports {i_fx3_flag[3]}]
set_property PACKAGE_PIN J16 [get_ports {i_fx3_flag[2]}]
set_property PACKAGE_PIN N24 [get_ports {i_fx3_flag[1]}]
set_property PACKAGE_PIN P21 [get_ports {i_fx3_flag[0]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {i_fx3_flag[0]}]

# FX3 Data pin Locations
set_property PACKAGE_PIN T24 [get_ports {io_fx3_fdata[0]}]
set_property PACKAGE_PIN L23 [get_ports {io_fx3_fdata[1]}]
set_property PACKAGE_PIN L22 [get_ports {io_fx3_fdata[2]}]
set_property PACKAGE_PIN L24 [get_ports {io_fx3_fdata[3]}]
set_property PACKAGE_PIN N16 [get_ports {io_fx3_fdata[4]}]
set_property PACKAGE_PIN N17 [get_ports {io_fx3_fdata[5]}]
set_property PACKAGE_PIN R16 [get_ports {io_fx3_fdata[6]}]
set_property PACKAGE_PIN R17 [get_ports {io_fx3_fdata[7]}]
set_property PACKAGE_PIN N18 [get_ports {io_fx3_fdata[8]}]
set_property PACKAGE_PIN K25 [get_ports {io_fx3_fdata[9]}]
set_property PACKAGE_PIN K26 [get_ports {io_fx3_fdata[10]}]
set_property PACKAGE_PIN M20 [get_ports {io_fx3_fdata[11]}]
set_property PACKAGE_PIN L20 [get_ports {io_fx3_fdata[12]}]
set_property PACKAGE_PIN L25 [get_ports {io_fx3_fdata[13]}]
set_property PACKAGE_PIN M24 [get_ports {io_fx3_fdata[14]}]
set_property PACKAGE_PIN M25 [get_ports {io_fx3_fdata[15]}]
set_property PACKAGE_PIN R23 [get_ports {io_fx3_fdata[16]}]
set_property PACKAGE_PIN T23 [get_ports {io_fx3_fdata[17]}]
set_property PACKAGE_PIN R22 [get_ports {io_fx3_fdata[18]}]
set_property PACKAGE_PIN T22 [get_ports {io_fx3_fdata[19]}]
set_property PACKAGE_PIN P26 [get_ports {io_fx3_fdata[20]}]
set_property PACKAGE_PIN R26 [get_ports {io_fx3_fdata[21]}]
set_property PACKAGE_PIN T25 [get_ports {io_fx3_fdata[22]}]
set_property PACKAGE_PIN M26 [get_ports {io_fx3_fdata[23]}]
set_property PACKAGE_PIN N26 [get_ports {io_fx3_fdata[24]}]
set_property PACKAGE_PIN P25 [get_ports {io_fx3_fdata[25]}]
set_property PACKAGE_PIN R25 [get_ports {io_fx3_fdata[26]}]
set_property PACKAGE_PIN R21 [get_ports {io_fx3_fdata[27]}]
set_property PACKAGE_PIN R20 [get_ports {io_fx3_fdata[28]}]
set_property PACKAGE_PIN P24 [get_ports {io_fx3_fdata[29]}]
set_property PACKAGE_PIN P23 [get_ports {io_fx3_fdata[30]}]
set_property PACKAGE_PIN N19 [get_ports {io_fx3_fdata[31]}]

set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[31]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[30]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[29]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[28]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[27]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[26]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[25]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[24]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[23]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[22]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[21]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[20]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[19]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[18]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[17]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[16]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[15]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[14]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[13]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[12]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[11]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[10]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[9]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[8]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[6]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[5]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[2]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[1]}]
set_property IOSTANDARD LVCMOS33 [get_ports {io_fx3_fdata[0]}]

# Configuration Mode
# Slave_Select_Map
set_property CONFIG_MODE S_SELECTMAP16 [current_design]
set_property BITSTREAM.CONFIG.EXTMASTERCCLK_EN DIV-1 [current_design]